"""
Unittests for emoji.unicode_codes
"""


import emoji.unicode_codes


def test_emoji_names():

    for name in emoji.unicode_codes.EMOJI_UNICODE.keys():
        assert name.startswith(':') and name.endswith(':') and len(name) >= 3



# -*- coding: UTF-8 -*-

"""
emoji.core
~~~~~~~~~~

Core components for emoji.

"""


import re

from . import unicode_codes


def emojize(string, is_short=True):
    """Replace emoji names in a string with unicode codes.

    :param string: String contains emoji names.
    :param is_short: (optional) Whether uses aliase of emoji name or not.

        >>> import emoji
        >>> print(emoji.emojize("Python is fun :thumbsup:"))
        Python is fun 👍
        >>> print(emoji.emojize("Python is fun :thumbs_up_sign:", False))
        Python is fun 👍
    """

    pattern = re.compile('(:[a-zA-Z0-9\+\-_]+:)')

    def replace(match):
        if is_short:
            return unicode_codes.EMOJI_SHORT_UNICODE.get(match.group(1), match.group(1))
        else:
            return unicode_codes.EMOJI_UNICODE.get(match.group(1), match.group(1))

    return pattern.sub(replace, string)


def decode(u_code, is_short=True):
    """Given a unicode code return the name of the associated emoji.

    :param u_code : String contains unicode emoji.
    :param is_short: (optional) Whether uses aliase of emoji name or not.
    :raises ValueError: unrecognized string.
    :return: Name of associated emoji.

        >>> import emoji
        >>> print(emoji.decode("👍"))
        :+1:
        >>> print(emoji.decode("👍", False))
        :thumbs_up_sign:
    """

    try:
        u_code = u_code.decode('utf-8')
    except:
        pass

    try:
        if is_short:
            return unicode_codes.UNICODE_EMOJI_SHORT[u_code]
        else:
            return unicode_codes.UNICODE_EMOJI[u_code]
    except KeyError:
        raise ValueError("Unicode code is not an emoji: %s" % u_code)



# -*- coding: UTF-8 -*-


"""
Unittests for emoji.core
"""


from __future__ import unicode_literals

import emoji


def test_emojize_name_only():
    for name in emoji.EMOJI_UNICODE.keys():
        actual = emoji.emojize(name)
        expected = emoji.EMOJI_UNICODE[name]
        assert expected == actual, "%s != %s" % (expected, actual)


def test_emojize_complicated_string():
    # A bunch of emoji's with UTF-8 strings to make sure the regex expression is functioning
    name_code = {
        ':flag_for_Ceuta_&_Melilla:': u'\U0001F1EA \U0001F1E6',
        ':flag_for_St._Barthélemy:': u'\U0001F1E7 \U0001F1F1',
        ':flag_for_Côte_d’Ivoire:': u'\U0001F1E8 \U0001F1EE',
        ':flag_for_Åland_Islands:': u'\U0001F1E6 \U0001F1FD',
        ':flag_for_São_Tomé_&_Príncipe:': u'\U0001F1F8 \U0001F1F9',
        ':flag_for_Curaçao:': u'\U0001F1E8 \U0001F1FC'
    }
    string = ' complicated! '.join(list(name_code.keys()))
    actual = emoji.emojize(string)
    expected = string
    for name, code in name_code.items():
        expected = expected.replace(name, code)
    expected = emoji.emojize(actual)
    assert expected == actual, "%s != %s" % (expected, actual)


def test_emojize_invalid_emoji():
    string = '__---___--Invalid__--__-Name'
    assert emoji.emojize(string) == string


def test_decode():

    for name, u_code in emoji.EMOJI_UNICODE.items():
        assert emoji.decode(u_code) == name


def test_decode_invalid_string():
    try:
        emoji.decode('__---___--Invalid__--__-Name')
        raise Exception("Above line should have raised a ValueError")
    except ValueError:
        pass



#!/usr/bin/env python
# -*- coding: UTF-8 -*-


"""
Setup script for emoji
"""


import os
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


with open('README.rst') as f:
    readme_content = f.read().strip()


with open('LICENSE.txt') as f:
    license_content = f.read().strip()


version = None
author = None
email = None
source = None
with open(os.path.join('emoji', '__init__.py')) as f:
    for line in f:
        if line.strip().startswith('__version__'):
            version = line.split('=')[1].strip().replace('"', '').replace("'", '')
        elif line.strip().startswith('__author__'):
            author = line.split('=')[1].strip().replace('"', '').replace("'", '')
        elif line.strip().startswith('__email__'):
            email = line.split('=')[1].strip().replace('"', '').replace("'", '')
        elif line.strip().startswith('__source__'):
            source = line.split('=')[1].strip().replace('"', '').replace("'", '')
        elif None not in (version, author, email, source):
            break

setup(
    name='emoji',
    author=author,
    author_email=email,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: BSD License',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Multimedia :: Graphics :: Presentation',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    description="Emoji for Python",
    keywords=['emoji'],
    include_package_data=True,
    license=license_content,
    long_description=readme_content,
    packages=['emoji'],
    url=source,
    version=version,
    zip_safe=True,
)
